# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),

## [1.2.1] - 2021-03-26
### Changed
- Update package setup.py


## [1.2.0] - 2021-03-26
### Changed
- Add tracking support additional fields.


## [1.1.0] - 2020-08-17
A dummy version, NO CHANGES.


## [1.0.post2] - 2020-03-11
### Changed
- Dump version.


## [1.0.post1] - 2020-03-11
### Changed
- Fix import aftership problem [#15](https://github.com/AfterShip/aftership-sdk-python/issues/15).


## [1.0] - 2020-03-10
### Added
- Python 3.5+ support.

### Changed
- This package is not compatible with previous releases.

### Removed
- Python 2.X support.

[1.2.1]: https://github.com/AfterShip/aftership-sdk-python/releases/tag/1.2.1
[1.2.0]: https://github.com/AfterShip/aftership-sdk-python/releases/tag/1.2.0
[1.1.0]: https://github.com/AfterShip/aftership-sdk-python/releases/tag/1.1.0
[1.0.post2]: https://github.com/AfterShip/aftership-sdk-python/releases/tag/1.0.post2
[1.0.post1]: https://github.com/AfterShip/aftership-sdk-python/releases/tag/1.0.post1
[1.0]: https://github.com/AfterShip/aftership-sdk-python/releases/tag/1.0
